@@ -12,6 +12,7 @@ import platform
 import functools
 import subprocess
 import collections
+import collections.abc as cabc
 import importlib.util
 
 from xonsh.lazyasd import LazyBool, lazyobject, lazybool
@@ -75,6 +76,12 @@ def ON_BEOS():
     return sys.platform == "beos5" or sys.platform == "haiku1"
 
 
+@lazybool
+def ON_WSL():
+    """True if we are on Windows Subsystem for Linux (WSL)"""
+    return "Microsoft" in platform.release()
+
+
 #
 # Python & packages
 #
@@ -90,7 +97,7 @@ def PYTHON_VERSION_INFO_BYTES():
 
 
 ON_ANACONDA = LazyBool(
-    lambda: any(s in sys.version for s in {"Anaconda", "Continuum", "conda-forge"}),
+    lambda: pathlib.Path(sys.prefix).joinpath("conda-meta").exists(),
     globals(),
     "ON_ANACONDA",
 )
@@ -193,7 +200,9 @@ def ptk_below_max_supported():
 
 @functools.lru_cache(1)
 def best_shell_type():
-    if ON_WINDOWS or has_prompt_toolkit():
+    if builtins.__xonsh__.env.get("TERM", "") == "dumb":
+        return "dumb"
+    elif ON_WINDOWS or has_prompt_toolkit():
         return "prompt_toolkit"
     else:
         return "readline"
@@ -347,7 +356,7 @@ def linux_distro():
     if ON_LINUX:
         if distro:
             ld = distro.id()
-        elif PYTHON_VERSION_INFO < (3, 7, 0):
+        elif PYTHON_VERSION_INFO < (3, 6, 6):
             ld = platform.linux_distribution()[0] or "unknown"
         elif "-ARCH-" in platform.platform():
             ld = "arch"  # that's the only one we need to know for now
@@ -382,7 +391,7 @@ def windows_bash_command():
     # Check that bash is on path otherwise try the default directory
     # used by Git for windows
     wbc = "bash"
-    cmd_cache = builtins.__xonsh_commands_cache__
+    cmd_cache = builtins.__xonsh__.commands_cache
     bash_on_path = cmd_cache.lazy_locate_binary("bash", ignore_alias=True)
     if bash_on_path:
         try:
@@ -415,7 +424,7 @@ def windows_bash_command():
 
 if ON_WINDOWS:
 
-    class OSEnvironCasePreserving(collections.MutableMapping):
+    class OSEnvironCasePreserving(cabc.MutableMapping):
         """ Case-preserving wrapper for os.environ on Windows.
             It uses nt.environ to get the correct cased keys on
             initialization. It also preserves the case of any variables
