@@ -1089,6 +1089,11 @@ def swap_values(d, updates, default=_DEFAULT_SENTINEL):
 #
 
 
+def detype(x):
+    """This assumes that the object has a detype method, and calls that."""
+    return x.detype()
+
+
 def is_int(x):
     """Tests if something is an integer"""
     return isinstance(x, int)
@@ -1134,6 +1139,11 @@ def always_false(x):
     return False
 
 
+def always_none(x):
+    """Returns None"""
+    return None
+
+
 def ensure_string(x):
     """Returns a string if x is not a string, and x if it already is."""
     return str(x)
@@ -2115,7 +2125,9 @@ def expandvars(path):
             name = match.group("envvar")
             if name in env:
                 ensurer = env.get_ensurer(name)
-                value = ensurer.detype(env[name])
+                val = env[name]
+                value = str(val) if ensurer.detype is None else ensurer.detype(val)
+                value = str(val) if value is None else value
                 path = POSIX_ENVVAR_REGEX.sub(value, path, count=1)
     return path
 
